This script aims to transform tmc file into gmns format. Then after map-matching program
of MapMatching4GMNS, the link file generated from tmc file is matched to the underlying network (here is gmns format of osm map). 
In the end, the link performance file of underlying network is generated with tmc file and the corresponding reading file.